==> divine-3.90.1+2016.12.13.tar.gz: divine-3.90.1+2016.12.13/doc/website/download.md <==
DIVINE is **free software**, distributed under the **ISC licence** (2-clause
**BSD**). De­tailed licence texts may be found in the doc/COPYING file in the
distribution tarball. The distribution tarball includes freely redistributable
**third-party code**. Please refer to AUTHORS and COPYING included in the
distribution for co­pyright and licensing details.

Download
========

The latest release of DIVINE is **4.0 beta**, available as a source tarball:
[divine-@version@.tar.gz](download/divine-@version@.tar.gz). You can also download
[nightly snapshots] [6] or fetch the source code from our version control
repository (you may need to install [darcs] [3]):

    $ darcs get http://divine.fi.muni.cz/current divine

To build the sources, you only need to run `make`. For a summary of changes
between releases, please consult our [release notes] [1] and for help with
installation, [detailed installation instructions] [4] are available in our
[manual] [5].

Alternatively, you can also download [older versions] [2]. Please note,
however, that DiVinE Cluster, DiVinE Multi-Core and ProbDiVinE have been
discontinued and the 3.x branch of DIVINE is no longer actively maintained
either.

Virtual Machine Images
----------------------

Since building DIVINE can be a time-consuming process, once a stable release of
DIVINE 4 is available, we will provide pre-built VM images for quick
evaluation.

[1]: whatsnew.html
[2]: download
[3]: http://darcs.net
[4]: manual.html#installation
[5]: manual.html
[6]: download/snapshots/

==> divine-4.0.1.tar.gz: divine-4.0.1/doc/website/download.md <==
DIVINE is **free software**, distributed under the **ISC licence** (2-clause
**BSD**). De­tailed licence texts may be found in the doc/COPYING file in the
distribution tarball. The distribution tarball includes freely redistributable
**third-party code**. Please refer to `doc/AUTHORS` and `doc/COPYING` included in the
distribution for co­pyright and licensing details.

Download
========

The latest release of DIVINE is **4.0**, available as a source tarball:
[divine-@version@.tar.gz](download/divine-@version@.tar.gz). You can also download
[nightly snapshots] [6] or fetch the source code from our version control
repository (you may need to install [darcs] [3]):

    $ darcs get http://divine.fi.muni.cz/current divine

To build the sources, you only need to run `make`. For a summary of changes
between releases, please consult our [release notes] [1] and for help with
installation, [detailed installation instructions] [4] are available in our
[manual] [5].

Alternatively, you can also download [older versions] [2]. Please note,
however, that DiVinE Cluster, DiVinE Multi-Core and ProbDiVinE have been
discontinued and the 3.x branch of DIVINE is no longer actively maintained
either.

Virtual Machine Images
----------------------

Since building DIVINE can be a time-consuming process, once a stable release of
DIVINE 4 is available, we will provide pre-built VM images for quick
evaluation.

[1]: whatsnew.html
[2]: download
[3]: http://darcs.net
[4]: manual.html#installation
[5]: manual.html
[6]: download/snapshots/
